package Ryu::Buffer;

use strict;
use warnings;

our $VERSION = '1.011'; # VERSION

use parent qw(Ryu::Node);

=encoding utf8

=head1 NAME

Ryu::Buffer - accumulate data

=head1 DESCRIPTION



=cut

=head1 METHODS

__CUT__

1;

__END__

=head1 AUTHOR

Tom Molesworth <TEAM@cpan.org>

=head1 LICENSE

Copyright Tom Molesworth 2019-2020. Licensed under the same terms as Perl itself.

